.. Internet Graphic Service example scripts

Internet Graphic Service Example scripts
========================================

``igs_http_imgconv``
--------------------

This example script demonstrate the use of the ``IGS`` interpreter ``IMGCONV`` through HTTP
listener to convert a provided ``jpg`` file to the ``png`` format with a 100x100 size.


``igs_http_xmlchart``
---------------------

This example script demonstrate the use of the ``IGS`` interpreter through HTTP listener
to generate a simple chart. The input of the chart is provided in ``XML`` format and the
script will print the generated charts' URLs.


``igs_http_zipper``
-------------------

This example script demonstrate the use of the ``IGS`` interpreter ``ZIPPER`` through HTTP
listener to compress an input file to a ``zip`` file. The script will print the generated
``zip`` files URLs.


``igs_rfc_zipper``
------------------

This example script demonstrate the use of the ``IGS`` interpreter ``ZIPEER`` through RFC
listener to compress an input file to a ``zip`` file.
